# API Keys Settings

> View your OpenHands LLM key and create API keys to work with OpenHands programmatically.

<Note>
  These settings are only available in [OpenHands Cloud](/openhands/usage/cloud/openhands-cloud).
</Note>

## Overview

Use the API Keys settings page to manage your OpenHands LLM key and create API keys for programmatic access to
OpenHands Cloud

## OpenHands LLM Key

You can use the API key under `OpenHands LLM Key` with [the OpenHands CLI](/openhands/usage/run-openhands/cli-mode),
[running OpenHands on your own](/openhands/usage/run-openhands/local-setup), or even other AI coding agents. This will
use credits from your OpenHands Cloud account. If you need to refresh it at anytime, click the `Refresh API Key` button.

## OpenHands API Key

These keys can be used to programmatically interact with OpenHands Cloud. See the guide for using the
[OpenHands Cloud API](/openhands/usage/cloud/cloud-api).

### Create API Key

1. Navigate to the `Settings > API Keys` page.
2. Click `Create API Key`.
3. Give your API key a name and click `Create`.

### Delete API Key

1. On the `Settings > API Keys` page, click the `Delete` button next to the API key you'd like to remove.
2. Click `Delete` to confirm removal.


---

> To find navigation and other pages in this documentation, fetch the llms.txt file at: https://docs.openhands.dev/llms.txt